#!/bin/sh

##########################################################################
# This script will install the EGL library (which contains the necessary #
# service program to run your EGL application), create a symlink so that #
# java can use this service program, and will show what env vars need to #
# be set.                                                                #
##########################################################################

# VARS
savefile=EGLSAV.SAVF
syssavefile=EGLSAV.FILE
link=libcsodstct7.so

# function: createLink
# desc:     create a symlink to the srvpgm so java can load it
function createLink() {
	echo Creating symlink required by java to find the service program...
	if [ -h $link ]; then
		echo $link already exists...backing up to $link.old
		mv $link $link.old
	fi
	
	ln -s /qsys.lib/egl.lib/libcsodstc.srvpgm $link
	if [ -h $link ]; then
		echo $link created successfully
	else
		echo There was an unknown problem creating the symlink
		echo Try manually creating a symlink called libcsodstct7.so to /qsys.lib/egl.lib/libcsodstc.srvpgm
	fi
}


# function: installLibrary
# desc:     installs the EGL library
function installLibrary() {
	# copy library save file to /qsys.lib
	if [ -f $savefile ]; then
		cp $savefile /qsys.lib/$syssavefile
	else
		echo \* ERROR: $savefile not found! Please copy it into this directory to install
		return
	fi
	
	# CL command to install ("restore") the EGL library
	system -q "RSTLIB SAVLIB(EGL) DEV(*SAVF) SAVF(*LIBL/EGLSAV)"
	echo EGL Library installed containing service program libcsodstc.srvpgm
	
	# remove the file we copied
	rm /qsys.lib/$syssavefile
	
	# create symlink
	echo
	createLink
}


# function: displayUsage
# desc:     displays usage of this script
function displayUsage() {
	echo Usage: setup.sh option
	echo
	echo OPTIONS:
	echo install - installs required EGL service program
	echo link - creates necessary symlink for java - done by install, but useful if you delete the link
	echo envinfo - displays the environment variables you need to set
	echo help - displays this message
}


# function: showEnvInfo
# desc:     displays what vars need to be set
function showEnvInfo() {
	echo Enviroment Variable Info:
	echo
	echo You need the following environment variables set:
	echo LIBPATH: must include the directory where the symlink to the service program resides
	echo CLASSPATH: must include the two runtime jar file fda7.jar, and also the directory you will be invoking java from
	echo
	echo Example - assuming everything is in the current working directory:
	echo export LIBPATH=\$LIBPATH:$PWD
	echo export CLASSPATH=\$CLASSPATH:$PWD:$PWD/fda7.jar
}


# main execution

if [ -z $1 ]; then
	displayUsage
else
	# process arg
	echo
	case $1 in
		envinfo) showEnvInfo;;
		install) installLibrary;;
		link) createLink;;
		help) displayUsage;;
		*) echo \* INVALID OPTION: $1; echo; displayUsage;;
	esac
fi
